@@ -58,6 +58,10 @@ static int handler(void* setting, const char* section, const char* name, const c
         config->profile = strdup(value);
     } else if (MATCH("control", "turtle")) {
         config->turtle = atoi(value);
+    } else if (MATCH("control", "proximity")) {
+        config->proximity = atoi(value);
+    } else if (MATCH("control", "autofire0")) {
+        config->autofire0 = atoi(value);
     }
 }
 
@@ -79,6 +83,15 @@ inline int read_accel(int *x, int *y, int *z)
   return 1;
 }
 
+char read_prox()
+{
+  FILE *fd;
+  char proximity;
+  fd = fopen(prox_filename,"r");
+  proximity = fgetc(fd); // 'o'pen or 'c'losed
+  fclose(fd);
+  return proximity;
+}
 
 // Abstracts the raw accelerometer readings as follows:
 // * creates an average of samples# of readings sample_interval microseconds apart
@@ -147,6 +160,8 @@ int init(char* config_file, void* config) // Returns filedescriptor for uinput d
 
 int main(int argc, char **argv)
 {
+  char proximity;
+  int button0 = 0;
   int uinput_fd; 
   int ax, ay, az;
   float acc; // Total acceleration (Sqrt of sum of squares)
@@ -173,6 +188,9 @@ int main(int argc, char **argv)
   while(1) { // Begin main loop. This only exits if a trigger file that was specified is deleted.
 
     read_errors+= do_poll(config.samples, &sample_interval, &ax, &ay, &az);
+    if (config.proximity){
+      proximity = read_prox();
+    }
     frames++;
 
     // Monitor the state of the config file and trigger file infrequently
@@ -191,20 +209,23 @@ int main(int argc, char **argv)
       }
     }
 
-    // Handle turtle mode if user has flipped phone upside down
-    if (config.turtle && az > 750) { // TODO: may need filtering to avoid accidental activation during motion if poll time is short
-      turtle_timer = time(0); // Not used, but could e.g. shutdown service if left upside down
-      sample_interval.tv_nsec = ONE_SECOND * 3lu;
-      while (!do_poll(1, &sample_interval, &ax, &ay, &az) && az > 100) // Poll slowly until flipped face-up again.
+    /* Handle turtle mode if:
+         user has flipped phone upside down
+         or proximity is covered and that is enabled*/
+    if (config.turtle && az > 750 || config.proximity == 1 && proximity == 'c' ) { // TODO: may need filtering to avoid accidental activation during motion if poll time is short
+      turtle_timer = time(0); // Only used to decide whether to toggle (<10 s), but could e.g. shutdown service if left upside down
+      sample_interval.tv_nsec = ONE_SECOND * 2lu;
+      while (!do_poll(1, &sample_interval, &ax, &ay, &az) && az > 100 || config.proximity ==1 && read_prox() == 'c') // Poll slowly until flipped face-up again and proximity sensor is uncovered.
         if (trigger_filename[0] && access(trigger_filename, F_OK)) break; // Don't forget to check for shutdown
-      if (config.turtle < 0) { 
-        config.turtle = 1; // Turtle enabled but inactive
+      if (config.turtle < 0 || turtle_timer && time(0) - turtle_timer > 10 ) {
+        turtle_timer = 0; 
+        config.turtle = 1; // Turtle now enabled but inactive
         sample_interval.tv_nsec = ONE_SECOND / (config.frame_rate * config.samples);
       } else { 
         // Center joystick before turtling
         do_uinput(uinput_fd, ABS_X, 0, EV_ABS);
         do_uinput(uinput_fd, ABS_Y, 0, EV_ABS);
-        config.turtle = -1; 
+        config.turtle = -1; // Turtle active now; time to sleep
         sample_interval.tv_nsec = ONE_SECOND / 2.5;
       }
     }
@@ -221,7 +242,22 @@ int main(int argc, char **argv)
       printf("Frame: acceleration(%d,%d,%d)=%.0f. Tilt (%0.2f,%0.2f) with offset %0.2f included.\n",ax,ay,az,acc,current.pitch, current.roll, config.offset_pitch);
 
     clamp(&current.pitch, config.max_pitch), clamp(&current.roll, config.max_roll);
-    
+
+    // Handle proximity sensor as a button
+    if (config.proximity == 2) {
+      if (proximity == 'c') {
+        if (!button0 || config.autofire0){
+          button0++;
+          do_uinput(uinput_fd, BTN_A, 1, EV_KEY); // Send simulated button press to UINPUT
+        }
+      } else {
+        if (button0){
+          button0 = 0;
+          do_uinput(uinput_fd, BTN_A, 0, EV_KEY); // Send simulated button release to UINPUT
+        }
+      }
+    }
+
     // Send significantly changed control states to UINPUT
     if ((current.roll-previous.roll) * (current.roll-previous.roll) > config.threshold_roll*config.threshold_roll) // abs()
     {
