@@ -6,7 +6,7 @@
 
 #include <time.h> // nanosleep()
 
-#define VERSION "0.0.3"
+#define VERSION "0.0.7"
 #define MAX_AXIS 0xFFFF		// SDL's joystick axis is stored in 16 bit int
 #define PI 3.1415
 #define ONE_SECOND 1000000000lu	// for nanosleep			
@@ -20,6 +20,9 @@ char* config_file = "/home/user/.accelemymote/main.cfg";
 static const char *accel_filename = "/sys/class/i2c-adapter/i2c-3/3-001d/coord";
 //static const char *accel_filename = "/tmp/accel"; 	//For testing in SDK. You can cat eg "0 500 500" to the file.
 
+/* Proximity device file */
+static const char *prox_filename = "/sys/devices/platform/gpio-switch/proximity/state";
+
 /* Trigger file. When it goes, shutdown. Empty string for no kill file **This will eat about 0.5% CPU cycles until you kill it**.*/
 static const char *trigger_filename = "/home/user/.accelemymote/live-trigger";	// Yes i'm an evil evil man for hardcoding this. TODO: make parameter
 
@@ -30,6 +33,9 @@ typedef struct
 	int frame_rate;	// number of event-generating timesteps per second
 	int turtle;	// Turtle goes to sleep when upside down, and is turned on and off in the process.
 
+	int proximity;	// Enables proximity sensor. 1 Gives it similar behavior to flipping for turtle mode and 2 makes it button0
+	int autofire0;	// Enables per-frame spamming of a button 0 press.
+
 	int flip_pitch;	// -1=> tilt forward is up; 1=> tilt forward is down
 	float offset_pitch;	// The amount of backwards tilt to the neutral position (from flat, face up)
 	float max_roll;	// The greatest tilt that will be detected, in degrees
